@@ -149,10 +149,10 @@ sub requires {
 ##  if ( ! $self->distribution() ) {
 ##  }
     return +{
-	'Astro::Coord::ECI'		=> 0.102,
-	'Astro::Coord::ECI::Mixin'	=> 0.102,
-	'Astro::Coord::ECI::Sun'	=> 0.102,
-	'Astro::Coord::ECI::Utils'	=> 0.102,
+	'Astro::Coord::ECI'		=> 0.131,
+	'Astro::Coord::ECI::Mixin'	=> 0.131,
+	'Astro::Coord::ECI::Sun'	=> 0.131,
+	'Astro::Coord::ECI::Utils'	=> 0.131,	# for gm_strftime()
 	'Carp'		=> 0,
 	'Exporter'	=> 0,
 	'POSIX'		=> 0,
@@ -350,7 +350,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2018-2021 by Thomas R. Wyant, III
+Copyright (C) 2018-2022, 2024 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
